#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class MarkerSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         MarkerSettingAtt
                | 
                | Interface to handle the Marker settings
                | 
                | The different settings are:
                | 
                | MarkerAutoUpdate
                | Update on product structure modifications and scenes
                | activation.
                | 
                | 
                | MarkerDefaultsColor
                | 
                | 
                | MarkerDefaultsWeight
                | 
                | 
                | MarkerDefaultsDashed
                | 
                | 
                | Marker2DAutoNaming
                | 
                | 
                | Marker3DAutoNaming
                | 
                | 
                | MarkerTextColor2D
                | 
                | 
                | MarkerTextWeight2D
                | 
                | 
                | MarkerTextDashed2D
                | 
                | 
                | MarkerTextDefaultsFont2D
                | 
                | 
                | MarkerTextDefaultsSize2D
                | 
                | 
                | MarkerTextColor3D
                | 
                | 
                | MarkerTextWeight3D
                | 
                | 
                | MarkerTextDashed3D
                | 
                | 
                | MarkerTextDefaultsFont3D
                | 
                | 
                | MarkerTextDefaultsSize3D

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.marker_setting_att = com_object

    @property
    def marker_2d_auto_naming(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Marker2DAutoNaming() As boolean
                | 
                |     Returns or sets the activation state for 2D annotations automatic naming
                |     (TRUE naming is automatic, FALSE the naming is not automatic).

        :rtype: bool
        """

        return self.marker_setting_att.Marker2DAutoNaming

    @marker_2d_auto_naming.setter
    def marker_2d_auto_naming(self, value: bool):
        """
        :param bool value:
        """

        self.marker_setting_att.Marker2DAutoNaming = value

    @property
    def marker_3d_auto_naming(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Marker3DAutoNaming() As boolean
                | 
                |     Returns or sets the activation state for 3D annotations automatic naming
                |     (TRUE naming is automatic, FALSE the naming is not automatic).

        :rtype: bool
        """

        return self.marker_setting_att.Marker3DAutoNaming

    @marker_3d_auto_naming.setter
    def marker_3d_auto_naming(self, value: bool):
        """
        :param bool value:
        """

        self.marker_setting_att.Marker3DAutoNaming = value

    @property
    def marker_defaults_dashed(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MarkerDefaultsDashed() As long
                | 
                |     Returns or sets the default dashed value of an annotation (oValue the
                |     dashed value).

        :rtype: int
        """

        return self.marker_setting_att.MarkerDefaultsDashed

    @marker_defaults_dashed.setter
    def marker_defaults_dashed(self, value: int):
        """
        :param int value:
        """

        self.marker_setting_att.MarkerDefaultsDashed = value

    @property
    def marker_defaults_weight(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MarkerDefaultsWeight() As long
                | 
                |     Returns or sets the default weight value of an annotation (oValue the
                |     weight value).

        :rtype: int
        """

        return self.marker_setting_att.MarkerDefaultsWeight

    @marker_defaults_weight.setter
    def marker_defaults_weight(self, value: int):
        """
        :param int value:
        """

        self.marker_setting_att.MarkerDefaultsWeight = value

    @property
    def marker_text_dashed_2d(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MarkerTextDashed2D() As long
                | 
                |     Returns or sets the default dashed value of a 2D text annotation (oValue
                |     the dashed value).

        :rtype: int
        """

        return self.marker_setting_att.MarkerTextDashed2D

    @marker_text_dashed_2d.setter
    def marker_text_dashed_2d(self, value: int):
        """
        :param int value:
        """

        self.marker_setting_att.MarkerTextDashed2D = value

    @property
    def marker_text_dashed_3d(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MarkerTextDashed3D() As long
                | 
                |     Returns or sets the default dashed value of a 3D text annotation (oValue
                |     the dashed value).

        :rtype: int
        """

        return self.marker_setting_att.MarkerTextDashed3D

    @marker_text_dashed_3d.setter
    def marker_text_dashed_3d(self, value: int):
        """
        :param int value:
        """

        self.marker_setting_att.MarkerTextDashed3D = value

    @property
    def marker_text_defaults_font_2d(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MarkerTextDefaultsFont2D() As CATBSTR
                | 
                |     Returns or sets the default font of a 2D annotation (oValue the font name).

        :rtype: str
        """

        return self.marker_setting_att.MarkerTextDefaultsFont2D

    @marker_text_defaults_font_2d.setter
    def marker_text_defaults_font_2d(self, value: str):
        """
        :param str value:
        """

        self.marker_setting_att.MarkerTextDefaultsFont2D = value

    @property
    def marker_text_defaults_font_3d(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MarkerTextDefaultsFont3D(CATBSTR iValue)
                | 
                |     Returns or sets the default font of a 3D annotation (oValue the font name).

        :rtype: str
        """

        return self.marker_setting_att.MarkerTextDefaultsFont3D

    @marker_text_defaults_font_3d.setter
    def marker_text_defaults_font_3d(self, value: str):
        """
        :param str value:
        """

        self.marker_setting_att.MarkerTextDefaultsFont3D = value

    @property
    def marker_text_defaults_size_2d(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MarkerTextDefaultsSize2D() As long
                | 
                |     Returns or sets the default size value of a 2d annotation (oValue the size
                |     value)..

        :rtype: int
        """

        return self.marker_setting_att.MarkerTextDefaultsSize2D

    @marker_text_defaults_size_2d.setter
    def marker_text_defaults_size_2d(self, value: int):
        """
        :param int value:
        """

        self.marker_setting_att.MarkerTextDefaultsSize2D = value

    @property
    def marker_text_defaults_size_3d(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MarkerTextDefaultsSize3D(long iValue)
                | 
                |     Returns or sets the default size value of a 3d annotation (oValue the size
                |     value)..

        :rtype: int
        """

        return self.marker_setting_att.MarkerTextDefaultsSize3D

    @marker_text_defaults_size_3d.setter
    def marker_text_defaults_size_3d(self, value: int):
        """
        :param int value:
        """

        self.marker_setting_att.MarkerTextDefaultsSize3D = value

    @property
    def marker_text_weight_2d(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MarkerTextWeight2D() As long
                | 
                |     Returns or sets the default weight value of a 2D text annotation (oValue
                |     the weight value).

        :rtype: int
        """

        return self.marker_setting_att.MarkerTextWeight2D

    @marker_text_weight_2d.setter
    def marker_text_weight_2d(self, value: int):
        """
        :param int value:
        """

        self.marker_setting_att.MarkerTextWeight2D = value

    @property
    def marker_text_weight_3d(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MarkerTextWeight3D(long iValue)
                | 
                |     Returns or sets the default weight value of a 3D text annotation (oValue
                |     the weight value).

        :rtype: int
        """

        return self.marker_setting_att.MarkerTextWeight3D

    @marker_text_weight_3d.setter
    def marker_text_weight_3d(self, value: int):
        """
        :param int value:
        """

        self.marker_setting_att.MarkerTextWeight3D = value

    def get_marker_2d_auto_naming_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarker2DAutoNamingInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Marker2DAutoNaming
                |     parameter.
                |     Role:Retrieves the state of the Marker2DAutoNaming parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarker2DAutoNamingInfo(io_admin_level, io_locked)

    def get_marker_3d_auto_naming_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarker3DAutoNamingInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Marker3DAutoNaming
                |     parameter.
                |     Role:Retrieves the state of the Marker3DAutoNaming parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarker3DAutoNamingInfo(io_admin_level, io_locked)

    def get_marker_defaults_color(self, o_red: int, o_green: int, o_blue: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetMarkerDefaultsColor(long oRed,
                | long oGreen,
                | long oBlue)
                | 
                |     Returns the default color of an annotation (oRed, oGreen, oBlue: RGB values
                |     of the color).

        :param int o_red:
        :param int o_green:
        :param int o_blue:
        :rtype: None
        """
        return self.marker_setting_att.GetMarkerDefaultsColor(o_red, o_green, o_blue)

    def get_marker_defaults_color_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerDefaultsColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerDefaultsColor
                |     parameter.
                |     Role:Retrieves the state of the MarkerDefaultsColor parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerDefaultsColorInfo(io_admin_level, io_locked)

    def get_marker_defaults_dashed_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerDefaultsDashedInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerDefaultsDashed
                |     parameter.
                |     Role:Retrieves the state of the MarkerDefaultsDashed parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerDefaultsDashedInfo(io_admin_level, io_locked)

    def get_marker_defaults_weight_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerDefaultsWeightInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerDefaultsWeight
                |     parameter.
                |     Role:Retrieves the state of the MarkerDefaultsWeight parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerDefaultsWeightInfo(io_admin_level, io_locked)

    def get_marker_text_color_2d(self, o_red: int, o_green: int, o_blue: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetMarkerTextColor2D(long oRed,
                | long oGreen,
                | long oBlue)
                | 
                |     Returns the default color of a 2D text annotation (oRed, oGreen, oBlue: RGB
                |     values of the color).

        :param int o_red:
        :param int o_green:
        :param int o_blue:
        :rtype: None
        """
        return self.marker_setting_att.GetMarkerTextColor2D(o_red, o_green, o_blue)

    def get_marker_text_color_2d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerTextColor2DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerTextColor2D
                |     parameter.
                |     Role:Retrieves the state of the MarkerTextColor2D parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerTextColor2DInfo(io_admin_level, io_locked)

    def get_marker_text_color_3d(self, o_red: int, o_green: int, o_blue: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetMarkerTextColor3D(long oRed,
                | long oGreen,
                | long oBlue)
                | 
                |     Returns the default color of a 3D text annotation (oRed, oGreen, oBlue: RGB
                |     values of the color).

        :param int o_red:
        :param int o_green:
        :param int o_blue:
        :rtype: None
        """
        return self.marker_setting_att.GetMarkerTextColor3D(o_red, o_green, o_blue)

    def get_marker_text_color_3d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerTextColor3DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerTextColor3D
                |     parameter.
                |     Role:Retrieves the state of the MarkerTextColor3D parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerTextColor3DInfo(io_admin_level, io_locked)

    def get_marker_text_dashed_2d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerTextDashed2DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerTextDashed2D
                |     parameter.
                |     Role:Retrieves the state of the MarkerTextDashed2D parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerTextDashed2DInfo(io_admin_level, io_locked)

    def get_marker_text_dashed_3d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerTextDashed3DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerTextDashed3D
                |     parameter.
                |     Role:Retrieves the state of the MarkerTextDashed3D parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerTextDashed3DInfo(io_admin_level, io_locked)

    def get_marker_text_defaults_font_2d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerTextDefaultsFont2DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerDefaultsFont2D
                |     parameter.
                |     Role:Retrieves the state of the MarkerDefaultsFont2D parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerTextDefaultsFont2DInfo(io_admin_level, io_locked)

    def get_marker_text_defaults_font_3d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerTextDefaultsFont3DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerDefaultsFont3D
                |     parameter.
                |     Role:Retrieves the state of the MarkerDefaultsFont3D parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerTextDefaultsFont3DInfo(io_admin_level, io_locked)

    def get_marker_text_defaults_size_2d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerTextDefaultsSize2DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerDefaultsSize2D
                |     parameter.
                |     Role:Retrieves the state of the MarkerDefaultsSize2D parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerTextDefaultsSize2DInfo(io_admin_level, io_locked)

    def get_marker_text_defaults_size_3d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerTextDefaultsSize3DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerDefaultsSize3D
                |     parameter.
                |     Role:Retrieves the state of the MarkerDefaultsSize3D parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerTextDefaultsSize3DInfo(io_admin_level, io_locked)

    def get_marker_text_weight_2d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerTextWeight2DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerTextWeight2D
                |     parameter.
                |     Role:Retrieves the state of the MarkerTextWeight2D parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerTextWeight2DInfo(io_admin_level, io_locked)

    def get_marker_text_weight_3d_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMarkerTextWeight3DInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the MarkerTextWeight3D
                |     parameter.
                |     Role:Retrieves the state of the MarkerTextWeight3D parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.marker_setting_att.GetMarkerTextWeight3DInfo(io_admin_level, io_locked)

    def set_marker_2d_auto_naming_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarker2DAutoNamingLock(boolean iLocked)
                | 
                |     Locks or unlocks the Marker2DAutoNaming parameter.
                |     Role:Locks or unlocks the Marker2DAutoNaming parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarker2DAutoNamingLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_2d_auto_naming_lock'
        # # vba_code = """
        # # Public Function set_marker_2d_auto_naming_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarker2DAutoNamingLock iLocked
        # #     set_marker_2d_auto_naming_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_3d_auto_naming_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarker3DAutoNamingLock(boolean iLocked)
                | 
                |     Locks or unlocks the Marker3DAutoNaming parameter.
                |     Role:Locks or unlocks the Marker3DAutoNaming parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarker3DAutoNamingLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_3d_auto_naming_lock'
        # # vba_code = """
        # # Public Function set_marker_3d_auto_naming_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarker3DAutoNamingLock iLocked
        # #     set_marker_3d_auto_naming_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_defaults_color(self, i_red: int, i_green: int, i_blue: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerDefaultsColor(long iRed,
                | long iGreen,
                | long iBlue)
                | 
                |     Sets the default color of an annotation (iRed, iGreen, iBlue: RGB values
                |     for the desired color)

        :param int i_red:
        :param int i_green:
        :param int i_blue:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerDefaultsColor(i_red, i_green, i_blue)

    def set_marker_defaults_color_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerDefaultsColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerDefaultsColor parameter.
                |     Role:Locks or unlocks the MarkerDefaultsColor parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerDefaultsColorLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_defaults_color_lock'
        # # vba_code = """
        # # Public Function set_marker_defaults_color_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerDefaultsColorLock iLocked
        # #     set_marker_defaults_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_defaults_dashed_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerDefaultsDashedLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerDefaultsDashed parameter.
                |     Role:Locks or unlocks the MarkerDefaultsDashed parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerDefaultsDashedLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_defaults_dashed_lock'
        # # vba_code = """
        # # Public Function set_marker_defaults_dashed_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerDefaultsDashedLock iLocked
        # #     set_marker_defaults_dashed_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_defaults_weight_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerDefaultsWeightLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerDefaultsWeight parameter.
                |     Role:Locks or unlocks the MarkerDefaultsColor parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerDefaultsWeightLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_defaults_weight_lock'
        # # vba_code = """
        # # Public Function set_marker_defaults_weight_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerDefaultsWeightLock iLocked
        # #     set_marker_defaults_weight_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_text_color_2d(self, i_red: int, i_green: int, i_blue: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextColor2D(long iRed,
                | long iGreen,
                | long iBlue)
                | 
                |     Sets the default color of a 2D text annotation (iRed, iGreen, iBlue: RGB
                |     values for the desired color).

        :param int i_red:
        :param int i_green:
        :param int i_blue:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextColor2D(i_red, i_green, i_blue)

    def set_marker_text_color_2d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextColor2DLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerTextColor2D parameter.
                |     Role:Locks or unlocks the MarkerTextColor2D parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextColor2DLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_text_color_2d_lock'
        # # vba_code = """
        # # Public Function set_marker_text_color_2d_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerTextColor2DLock iLocked
        # #     set_marker_text_color_2d_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_text_color_3d(self, i_red: int, i_green: int, i_blue: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextColor3D(long iRed,
                | long iGreen,
                | long iBlue)
                | 
                |     Sets the default color of a 3D text annotation (iRed, iGreen, iBlue: RGB
                |     values for the desired color).

        :param int i_red:
        :param int i_green:
        :param int i_blue:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextColor3D(i_red, i_green, i_blue)

    def set_marker_text_color_3d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextColor3DLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerTextColor3D parameter.
                |     Role:Locks or unlocks the MarkerTextColor3D parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextColor3DLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_text_color_3d_lock'
        # # vba_code = """
        # # Public Function set_marker_text_color_3d_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerTextColor3DLock iLocked
        # #     set_marker_text_color_3d_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_text_dashed_2d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextDashed2DLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerTextDashed parameter.
                |     Role:Locks or unlocks the MarkerTextDashed2D parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextDashed2DLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_text_dashed_2d_lock'
        # # vba_code = """
        # # Public Function set_marker_text_dashed_2d_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerTextDashed2DLock iLocked
        # #     set_marker_text_dashed_2d_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_text_dashed_3d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextDashed3DLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerTextDashed3D parameter.
                |     Role:Locks or unlocks the MarkerTextDashed3D parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextDashed3DLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_text_dashed_3d_lock'
        # # vba_code = """
        # # Public Function set_marker_text_dashed_3d_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerTextDashed3DLock iLocked
        # #     set_marker_text_dashed_3d_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_text_defaults_font_2d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextDefaultsFont2DLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerDefaultsFont2D parameter.
                |     Role:Locks or unlocks the MarkerDefaultsFont2D parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextDefaultsFont2DLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_text_defaults_font_2d_lock'
        # # vba_code = """
        # # Public Function set_marker_text_defaults_font_2d_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerTextDefaultsFont2DLock iLocked
        # #     set_marker_text_defaults_font_2d_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_text_defaults_font_3d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextDefaultsFont3DLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerDefaultsFont3D parameter.
                |     Role:Locks or unlocks the MarkerDefaultsSize3D parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextDefaultsFont3DLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_text_defaults_font_3d_lock'
        # # vba_code = """
        # # Public Function set_marker_text_defaults_font_3d_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerTextDefaultsFont3DLock iLocked
        # #     set_marker_text_defaults_font_3d_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_text_defaults_size_2d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextDefaultsSize2DLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerDefaultsSize2D parameter.
                |     Role:Locks or unlocks the MarkerDefaultsSize3D parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextDefaultsSize2DLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_text_defaults_size_2d_lock'
        # # vba_code = """
        # # Public Function set_marker_text_defaults_size_2d_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerTextDefaultsSize2DLock iLocked
        # #     set_marker_text_defaults_size_2d_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_text_defaults_size_3d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextDefaultsSize3DLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerDefaultsSize3D parameter.
                |     Role:Locks or unlocks the MarkerDefaultsSize3D parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextDefaultsSize3DLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_text_defaults_size_3d_lock'
        # # vba_code = """
        # # Public Function set_marker_text_defaults_size_3d_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerTextDefaultsSize3DLock iLocked
        # #     set_marker_text_defaults_size_3d_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_text_weight_2d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextWeight2DLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerTextWeight2D parameter.
                |     Role:Locks or unlocks the MarkerTextWeight2D parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextWeight2DLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_text_weight_2d_lock'
        # # vba_code = """
        # # Public Function set_marker_text_weight_2d_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerTextWeight2DLock iLocked
        # #     set_marker_text_weight_2d_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_marker_text_weight_3d_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMarkerTextWeight3DLock(boolean iLocked)
                | 
                |     Locks or unlocks the MarkerTextWeight3D parameter.
                |     Role:Locks or unlocks the MarkerTextWeight3D parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.marker_setting_att.SetMarkerTextWeight3DLock(i_locked)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_marker_text_weight_3d_lock'
        # # vba_code = """
        # # Public Function set_marker_text_weight_3d_lock(marker_setting_att)
        # #     Dim iLocked (2)
        # #     marker_setting_att.SetMarkerTextWeight3DLock iLocked
        # #     set_marker_text_weight_3d_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'MarkerSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.real_param import RealParam
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeConnect(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeConnect
                | 
                | Represents the hybrid shape connect curve object.
                | Role: To access the data of the hybrid shape connect curve object. This data
                | includes:
                | 
                |     The face to process
                |     The connection parameter.
                | 
                | Use the HybridShapeFactory to create a HybridShapeConnect
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_connect = com_object

    @property
    def base_curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BaseCurve() As Reference
                | 
                |     Returns or sets the base curve.
                |     Do not use this property

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_connect.BaseCurve)

    @base_curve.setter
    def base_curve(self, refernce_curve: Reference):
        """
        :param Reference refernce_curve:
        """

        self.hybrid_shape_connect.BaseCurve = refernce_curve.com_object

    @property
    def connect_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ConnectType() As long
                | 
                |     Returns or sets whether the connect curve is or should be created as
                |     a"Normal Connect" or with a "Base Curve".
                |     Legal values: 0 for the normal solution and 1 for base curve
                |     solution.
                | 
                |     Example:
                | 
                |           This example sets the mode to create the connect
                |           curve
                |          hybConnectCurve with a base curve.
                |          
                | 
                |          hybConnectCurve.Base Curve = 1

        :rtype: int
        """

        return self.hybrid_shape_connect.ConnectType

    @connect_type.setter
    def connect_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_connect.ConnectType = value

    @property
    def first_continuity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstContinuity() As long
                | 
                |     Gets or Sets the continuity on first curve.
                |     FirstContinuity = 0 : Point continuity = 1 : Tangency continuity = 2 : Curvature continuity

        :rtype: int
        """

        return self.hybrid_shape_connect.FirstContinuity

    @first_continuity.setter
    def first_continuity(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_connect.FirstContinuity = value

    @property
    def first_curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstCurve() As Reference
                | 
                |     Gets or Sets the first reference curve. new first reference curve

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_connect.FirstCurve)

    @first_curve.setter
    def first_curve(self, refernce_curve: Reference):
        """
        :param Reference refernce_curve:
        """

        self.hybrid_shape_connect.FirstCurve = refernce_curve.com_object

    @property
    def first_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstOrientation() As long
                | 
                |     Gets or Sets the orientation of first curve
                |     FirstOrientation = 1 : SameOrientation. = -1 : InvertOrientation. = 2 : KoOrientation

        :rtype: int
        """

        return self.hybrid_shape_connect.FirstOrientation

    @first_orientation.setter
    def first_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_connect.FirstOrientation = value

    @property
    def first_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstPoint() As Reference
                | 
                |     Gets or Sets the first reference point. new first reference point

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_connect.FirstPoint)

    @first_point.setter
    def first_point(self, refernce_curve: Reference):
        """
        :param Reference refernce_curve:
        """

        self.hybrid_shape_connect.FirstPoint = refernce_curve.com_object

    @property
    def first_tension(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstTension() As RealParam (Read Only)
                | 
                |     Returns the tension on the first curve making up the connect
                |     curve.
                | 
                |     Example:
                | 
                |           This example retrieves the tension of the first curve that makes
                |           up
                |          the connect curve hybConnect.
                |          
                | 
                |          Dim firstCurveTension As CATIARealParam
                |          firstCurveTension = hybConnect.FirstTension

        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_connect.FirstTension)

    @property
    def second_continuity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property SecondContinuity() As long
                | 
                |     Gets or Sets the continuity on second curve. SecondContinuity = 0 : Point continuity = 1 :
                |     Tangency continuity = 2 : Curvature continuity

        :rtype: int
        """

        return self.hybrid_shape_connect.SecondContinuity

    @second_continuity.setter
    def second_continuity(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_connect.SecondContinuity = value

    @property
    def second_curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondCurve() As Reference
                | 
                |     Gets or Sets the second reference curve. new second reference curve

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_connect.SecondCurve)

    @second_curve.setter
    def second_curve(self, refernce_curve: Reference):
        """
        :param Reference refernce_curve:
        """

        self.hybrid_shape_connect.SecondCurve = refernce_curve.com_object

    @property
    def second_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property SecondOrientation() As long
                | 
                |     Gets or Sets the orientation of second curve SecondOrientation = 1 : SameOrientation. = -1 :
                |     InvertOrientation. = 2 : KoOrientation

        :rtype: int
        """

        return self.hybrid_shape_connect.SecondOrientation

    @second_orientation.setter
    def second_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_connect.SecondOrientation = value

    @property
    def second_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondPoint() As Reference
                | 
                |     Gets or Sets the second reference point. new second reference point

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_connect.SecondPoint)

    @second_point.setter
    def second_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_connect.SecondPoint = reference_point.com_object

    @property
    def second_tension(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondTension() As RealParam (Read Only)
                | 
                |     Returns the tension on the second curve making up the connect
                |     curve.
                | 
                |     Example:
                | 
                |           This example retrieves the tension of the second curve that makes
                |           up
                |          the connect curve hybConnect.
                |          
                | 
                |          Dim secondCurveTension As CATIARealParam
                |          secondCurveTension = hybConnect.SecondTension

        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_connect.SecondTension)

    @property
    def trim(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Trim() As boolean
                | 
                |     Gets or Sets the trim mode. Trim = FALSE : Connected curves are not trimmed. = TRUE :
                |     Connected curves are trimmed.

        :rtype: bool
        """

        return self.hybrid_shape_connect.Trim

    @trim.setter
    def trim(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_connect.Trim = value

    def __repr__(self):
        return f'HybridShapeConnect(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_activity import ManufacturingActivity
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingSetup3(ManufacturingActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                        ManufacturingInterfaces.ManufacturingActivity
                |                             ManufacturingSetup3
                | 
                | A ManufacturingSetup 3 for a Manufacturing Document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_setup3 = com_object

    def add_fixture(self, i_geometry: AnyObject, i_product: AnyObject, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddFixture(AnyObject iGeometry,
                | AnyObject iProduct,
                | short iPosition)
                | 
                |     Add Fixture to part operation
                | 
                |     Parameters:
                | 
                |         iGeometry
                |             Geometry to assign 
                |         iProduct
                |             Product containing the geometry to assign. 
                |         iPosition
                |             Position of the geometry in the list (0 to append at the end of the
                |             list).

        :param AnyObject i_geometry:
        :param AnyObject i_product:
        :param int i_position:
        :rtype: None
        """
        return self.manufacturing_setup3.AddFixture(i_geometry.com_object, i_product.com_object, i_position)

    def __repr__(self):
        return f'ManufacturingSetup3(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PSPListOfObjects(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspListOfObjects
                | 
                | Represents a collection of Objects.
                | Role: Collection of Object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_list_of_objects = com_object

    @property
    def count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Count() As long (Read Only)
                | 
                |     Returns the number of objects in the list.
                | 
                |     Example:
                |         This example retrieves in NumberOfObjects the number of objects
                |         currently gathered in MyList.
                | 
                |          NumberOfObjects = MyList.Count

        :rtype: int
        """

        return self.psp_list_of_objects.Count

    def append(self, i_object: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Append(AnyObject iObject)
                | 
                |     Adds an object to the end of the list.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object to be added to the list. 
                | 
                |     Example:
                | 
                |           The following example appends an object to the list.
                |
                |          Dim MyObject As AnyObject
                |          Dim MyList As PspListOfObjects
                |          MyList.Append(MyObject)

        :param AnyObject i_object:
        :rtype: None
        """
        return self.psp_list_of_objects.Append(i_object.com_object)

    def item(self, i_index: int, i_interface_name: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(long iIndex,
                | CATBSTR iInterfaceName) As AnyObject
                | 
                |     Returns an object from its index in the list.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the first object in the collection is 1, and the index
                |             of the last object is Count. 
                |         iInterfaceName
                |             The interface name of oObj. 
                | 
                |     Returns:
                |         the retrieved object. 
                |     Example:
                | 
                |           The following example returns in the third object in the
                |           list.
                |
                |          Dim MyObject As PspID
                |          Dim MyList As PspListOfObjects
                |          Set MyObject = PspListOfObjects.Item(3,"CATIAPspID")

        :param int i_index:
        :param str i_interface_name:
        :rtype: AnyObject
        """
        return AnyObject(self.psp_list_of_objects.Item(i_index, i_interface_name))

    def remove_by_index(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveByIndex(long iIndex)
                | 
                |     Remove an object from the list by specifying its position in the
                |     list.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The position of the object to be removed in the list.
                |
                |     Example:
                | 
                |           The following example removes the second entry in the list. Please
                |           note that the list index starts with 1.
                |
                |          Dim MyList As PspListOfObjects
                |          MyList.RemoveByIndex (2)

        :param int i_index:
        :rtype: None
        """
        return self.psp_list_of_objects.RemoveByIndex(i_index)

    def __repr__(self):
        return f'PSPListOfObjects(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.knowledge_interfaces.optimization_constraint import OptimizationConstraint
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class OptimizationConstraints(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     OptimizationConstraints
                | 
                | Represents a collection of Optimization Constraint.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.optimization_constraints = com_object

    def add_constraint(self, constraint_expression: str) -> OptimizationConstraint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func AddConstraint(CATBSTR constraintExpression) As
                | OptimizationConstraint
                | 
                |     Adds a optimization constraint. This parameter must not be read only.

        :param str constraint_expression:
        :rtype: OptimizationConstraint
        """
        return OptimizationConstraint(self.optimization_constraints.AddConstraint(constraint_expression))

    def item(self, i_index: cat_variant) -> OptimizationConstraint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As OptimizationConstraint
                | 
                |     Returns an optimization constraint using its index or its name from the
                |     optimization constraints collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the optimization constraint to retrieve
                |             from the collection of optimization constraints. As a numerics, this index is
                |             the rank of the optimization constraint in the collection. The index of the
                |             first optimization constraint in the collection is 1, and the index of the last
                |             optimization constraint is Count. As a string, it is the name you assigned to
                |             the optimization constraint using the 
                | 
                |         AnyObject.Name property or when changing the optimization constraint
                |         name by the property panel. 
                |     Returns:
                |         The retrieved optimization constraint 
                |     Example:
                |         This example retrieves the last optimization constraint in the
                |         optimization constraints collection.
                | 
                |          Set lastConstraint = constraints.Item(constraints.Count)

        :param cat_variant i_index:
        :rtype: OptimizationConstraint
        """
        return OptimizationConstraint(self.optimization_constraints.Item(i_index))

    def remove_constraint(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub RemoveConstraint(CATVariant iIndex)
                | 
                |     Removes a given optimization constraint using its index or its name from
                |     the optimization constraints collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             the name of the constraint if argument is a string or the index of
                |             the constraint if argument is an integer.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.optimization_constraints.RemoveConstraint(i_index)

    def __getitem__(self, n: int) -> OptimizationConstraint:
        if (n + 1) > self.count:
            raise StopIteration

        return OptimizationConstraint(self.optimization_constraints.Item(n + 1))

    def __iter__(self) -> Iterator[OptimizationConstraint]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'OptimizationConstraints(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.i_dispatch import IDispatch


class CATBaseUnknown(IDispatch):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         CATBaseUnknown
                | 
                | Base class for creating interfaces and for implementing
                | interfaces.
                | Role: CATBaseUnknown supplies the infrastructure and the basic mechanisms to
                | create interface abstract classes and to manage interface pointers. It is also
                | the base class for classes which implements interfaces and for their extension
                | classes because it supplies the code for the interface methods QueryInterface,
                | AddRef and Release.
                | 
                | Copyright © 1999-2011, Dassault Systèmes. All rights reserved.
    
    """

    def __init__(self):
        super().__init__()

    def __repr__(self):
        return f'CatBaseUnknown()'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator
from typing import TYPE_CHECKING

from pycatia.product_structure_interfaces.publication import Publication
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant

if TYPE_CHECKING:
    from pycatia.in_interfaces.reference import Reference


class Publications(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Publications
                | 
                | The collection of the Product publications.
                | A Product object can aggregate one or zero Publications
                | collection.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.publications = com_object

    def add(self, i_public_name: str) -> Publication:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add(CATBSTR iPublicName) As Publication
                | 
                |     Adds a publication object to the product and returns a pointer to the
                |     publication object.
                | 
                |     Parameters:
                | 
                |         iPublicName
                |             The name of the publication 
                |         oPub
                |             The publication object
                | 
                |             Example: The following example adds a new publication object with
                |             the name "PubName" to the product and returns the publication object
                |             Pub1.
                | 
                |              Dim Prod1 As Product
                |              Set Pub1 = Prod1.Add(PubName)

        :param str i_public_name:
        :rtype: Publication
        """
        return Publication(self.publications.Add(i_public_name))

    def item(self, i_identifier: cat_variant) -> Publication:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIdentifier) As Publication
                | 
                |     Returns the publication object corresponding to the given publication
                |     name.
                | 
                |     Parameters:
                | 
                |         iIdentifier
                |             The name of the publication 
                |         oPub
                |             The publication object
                | 
                |             Example: The following example returns Pub1 publication object from
                |             the product referencing the published name PubId.
                | 
                |              Dim Prod1 As Product
                |              Set Pub1 = Prod1.Item(PubId)

        :param cat_variant i_identifier:
        :rtype: Publication
        """
        return Publication(self.publications.Item(i_identifier))

    def remove(self, i_identifier: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub Remove(CATBSTR iIdentifier)
                | 
                |     Removes a publication from the product.
                | 
                |     Parameters:
                | 
                |         iIdentifier
                |             The name of the publication
                | 
                |             Example: The following example removes the publication object
                |             corresponding to the name PubId.
                | 
                |              Dim Prod1 As Product
                |              Prod1.Remove(PubId)

        :param str i_identifier:
        :rtype: None
        """
        return self.publications.Remove(i_identifier)

    def set_direct(self, i_identifier: cat_variant, i_pointed: 'Reference') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetDirect(CATVariant iIdentifier,
                | Reference iPointed)
                | 
                |     Valuates a publication object directly with the object it
                |     publishes.
                | 
                |     Parameters:
                | 
                |         iIdentifier
                |             The name of the publication 
                |         iPointed
                |             The published object
                |             The following 
                | 
                |         Boundary objects is supported: Boundary
                | 
                |         Example: The following example valuates the publication object of
                |         product Prod1 having the name PubId with the reference object
                |         RefObject.
                | 
                |          Dim Prod1 As Product
                |          Prod1.SetDirect(PubId,RefObject)

        :param cat_variant i_identifier:
        :param Reference i_pointed:
        :rtype: None
        """
        return self.publications.SetDirect(i_identifier, i_pointed.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_direct'
        # # vba_code = """
        # # Public Function set_direct(publications)
        # #     Dim iIdentifier (2)
        # #     publications.SetDirect iIdentifier
        # #     set_direct = iIdentifier
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_relay(self, i_identifier: cat_variant, i_relayer: 'Publications', i_name_in_relay: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetRelay(CATVariant iIdentifier,
                | Publications iRelayer,
                | CATVariant iNameInRelay)
                | 
                |     Valuates a publication object with another publication
                |     object.
                | 
                |     Parameters:
                | 
                |         iIdentifier
                |             The name of the publication to be valuated 
                |         iRelayer
                |             The product aggregating the valuating intermediate publication
                |             object 
                |         iNameInRelay
                |             The name of the valuating publication object
                | 
                |             Example: The following example valuates the publication object of
                |             product Prod1 having the name PubId1 with the publication object of product
                |             Prod2 having the name PubId2.
                | 
                |              Dim Prod1 As Product
                |              Prod1.SetRelay(PubId1,Prod2,PubId2)

        :param cat_variant i_identifier:
        :param Publications i_relayer:
        :param cat_variant i_name_in_relay:
        :rtype: None
        """
        return self.publications.SetRelay(i_identifier, i_relayer.com_object, i_name_in_relay)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_relay'
        # # vba_code = """
        # # Public Function set_relay(publications)
        # #     Dim iIdentifier (2)
        # #     publications.SetRelay iIdentifier
        # #     set_relay = iIdentifier
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __getitem__(self, n: int) -> Publication:
        if (n + 1) > self.count:
            raise StopIteration

        return Publication(self.publications.Item(n + 1))

    def __iter__(self) -> Iterator[Publication]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'Publications(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeUnfold(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeUnfold
                | 
                | Represents the hybrid shape Unfold feature object.
                | Role: To access the data of the hybrid shape Unfold feature object. This data
                | includes:
                | 
                |     The shell to unfold
                |     The edges to tear
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeUnfold
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_unfold = com_object

    @property
    def direction_to_unfold(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DirectionToUnfold() As Reference
                | 
                |     Returns or sets the direction to unfold.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_unfold.DirectionToUnfold)

    @direction_to_unfold.setter
    def direction_to_unfold(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.hybrid_shape_unfold.DirectionToUnfold = reference.com_object

    @property
    def edge_to_tear_positioning_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EdgeToTearPositioningOrientation() As long
                | 
                |     Returns or sets the positioning orientation when the reference origin is
                |     located on an edge to tear.
                | 
                |         0= The orientation is undefined
                |         1= The orientation is the default one
                |         2= The orientation is inversed

        :rtype: int
        """

        return self.hybrid_shape_unfold.EdgeToTearPositioningOrientation

    @edge_to_tear_positioning_orientation.setter
    def edge_to_tear_positioning_orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_unfold.EdgeToTearPositioningOrientation = value

    @property
    def origin_to_unfold(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property OriginToUnfold() As Reference
                | 
                |     Returns or sets the origin to unfold.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_unfold.OriginToUnfold)

    @origin_to_unfold.setter
    def origin_to_unfold(self, reference_origin: Reference):
        """
        :param Reference reference_origin:
        """

        self.hybrid_shape_unfold.OriginToUnfold = reference_origin.com_object

    @property
    def surface_to_unfold(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SurfaceToUnfold() As Reference
                | 
                |     Returns or sets the surface to unfold.
                |     Sub-element(s) supported (see Boundary object): Face, TriDimFeatEdge and
                |     BiDimFeatEdge.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_unfold.SurfaceToUnfold)

    @surface_to_unfold.setter
    def surface_to_unfold(self, reference_surface: Reference):
        """
        :param Reference reference_surface:
        """

        self.hybrid_shape_unfold.SurfaceToUnfold = reference_surface.com_object

    @property
    def surface_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SurfaceType() As long
                | 
                |     Returns or sets the type of surface to unfold.
                | 
                |         0= The type of surface is not defined
                |         1= The type of surface is ruled
                |         2= The type of surface is all

        :rtype: int
        """

        return self.hybrid_shape_unfold.SurfaceType

    @surface_type.setter
    def surface_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_unfold.SurfaceType = value

    @property
    def target_orientation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TargetOrientationMode() As long
                | 
                |     Returns or sets the mode for target surface orientation.
                | 
                |         0= No axis inversion
                |         1= U inversion axis
                |         2= V inversion axis
                |         3= U inversion axis and V inversion axis
                |         4= U inversion axis and swap U and V axis
                |         5= V inversion axis and swap U and V axis
                |         6= U inversion axis, V inversion axis and swap U and V
                |         axis
                |         7= Swap U and V axis

        :rtype: int
        """

        return self.hybrid_shape_unfold.TargetOrientationMode

    @target_orientation_mode.setter
    def target_orientation_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_unfold.TargetOrientationMode = value

    @property
    def target_plane(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TargetPlane() As Reference
                | 
                |     Returns or sets the target plane.
                |     Sub-element(s) supported (see Boundary object):

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_unfold.TargetPlane)

    @target_plane.setter
    def target_plane(self, reference_plane: Reference):
        """
        :param Reference reference_plane:
        """

        self.hybrid_shape_unfold.TargetPlane = reference_plane.com_object

    def add_edge_to_tear(self, i_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddEdgeToTear(Reference iElement)
                | 
                |     Adds an edge to tear.
                | 
                |     Parameters:
                | 
                |         iEdge
                |             The edge to tear to add to the hybrid shape feature
                |             object.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): Edge 
                | 
                | Examples:
                |     The following example adds the iElement feature object to the
                |     HybridShapeUnfold object.
                | 
                |      HybridShapeUnfold.AddEdgeToTear iElement

        :param Reference i_element:
        :rtype: None
        """
        return self.hybrid_shape_unfold.AddEdgeToTear(i_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_edge_to_tear'
        # # vba_code = """
        # # Public Function add_edge_to_tear(hybrid_shape_unfold)
        # #     Dim iElement (2)
        # #     hybrid_shape_unfold.AddEdgeToTear iElement
        # #     add_edge_to_tear = iElement
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_element_to_transfer(self, i_element: Reference, i_type_of_transfer: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddElementToTransfer(Reference iElement,
                | long iTypeOfTransfer)
                | 
                |     Appends an element to transfer.
                | 
                |     Parameters:
                | 
                |         iElement
                |             Specification to transfer 
                |         iTypeOfTransfer
                |             type of tranfer
                | 
                |                 0= No transfer mode specified
                |                 1= Folded to unfolded
                |                 2= Unfolded to folded

        :param Reference i_element:
        :param int i_type_of_transfer:
        :rtype: None
        """
        return self.hybrid_shape_unfold.AddElementToTransfer(i_element.com_object, i_type_of_transfer)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_element_to_transfer'
        # # vba_code = """
        # # Public Function add_element_to_transfer(hybrid_shape_unfold)
        # #     Dim iElement (2)
        # #     hybrid_shape_unfold.AddElementToTransfer iElement
        # #     add_element_to_transfer = iElement
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_edge_to_tear(self, i_rank: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetEdgeToTear(long iRank) As Reference
                | 
                |     Retrieves an element used by the hybrid shape unfold feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iRank
                |             The rank of the element to read. 
                | 
                |     Examples:
                |         The following example gets the oElement feature object of the
                |         HybridShapeUnfold object at the position iRank.
                | 
                |          Dim oElement As Reference
                |          Set oElement = HybridShapeUnfold.GetEdgeToTear (iRank).

        :param int i_rank:
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_unfold.GetEdgeToTear(i_rank))

    def get_element_to_transfer(self, i_rank: int, op_element: Reference, o_type_of_transfer: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetElementToTransfer(long iRank,
                | Reference opElement,
                | long oTypeOfTransfer)
                | 
                |     Gets an element to transfer.
                | 
                |     Parameters:
                | 
                |         iRank
                |             the position of the specification to get 
                |         opElement
                |             Specification to transfer 
                |         oTypeOfTransfer
                |             type of tranfer
                | 
                |                 0= No transfer mode specified
                |                 1= Folded to unfolded
                |                 2= Unfolded to folded

        :param int i_rank:
        :param Reference op_element:
        :param int o_type_of_transfer:
        :rtype: None
        """
        return self.hybrid_shape_unfold.GetElementToTransfer(i_rank, op_element.com_object, o_type_of_transfer)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_element_to_transfer'
        # # vba_code = """
        # # Public Function get_element_to_transfer(hybrid_shape_unfold)
        # #     Dim iRank (2)
        # #     hybrid_shape_unfold.GetElementToTransfer iRank
        # #     get_element_to_transfer = iRank
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_edge_to_tear(self, i_rank: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveEdgeToTear(long iRank)
                | 
                |     Removes an element used by the hybrid shape unfold feature
                |     object.
                | 
                |     Parameters:
                | 
                |         iRank
                |             The rank of the element to remove. 
                | 
                |     Examples:
                |         The following example removes the feature object from the
                |         HybridShapeUnfold object at the position iRank.
                | 
                |          HybridShapeUnfold.RemoveEdgeToTear iRank.

        :param int i_rank:
        :rtype: None
        """
        return self.hybrid_shape_unfold.RemoveEdgeToTear(i_rank)

    def remove_element_to_transfer(self, i_rank: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveElementToTransfer(long iRank)
                | 
                |     Remove an elements to transfer.
                | 
                |     Parameters:
                | 
                |         iRank
                |             the position of the specification to remove

        :param int i_rank:
        :rtype: None
        """
        return self.hybrid_shape_unfold.RemoveElementToTransfer(i_rank)

    def replace_elements_to_transfer(self, i_rank: int, i_element: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReplaceElementsToTransfer(long iRank,
                | Reference iElement)
                | 
                |     Replace an elements to transfer.
                | 
                |     Parameters:
                | 
                |         iRank
                |             the position of the specification to replace 
                |         iElement
                |             the specification to transfer to append.

        :param int i_rank:
        :param Reference i_element:
        :rtype: None
        """
        return self.hybrid_shape_unfold.ReplaceElementsToTransfer(i_rank, i_element.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'replace_elements_to_transfer'
        # # vba_code = """
        # # Public Function replace_elements_to_transfer(hybrid_shape_unfold)
        # #     Dim iRank (2)
        # #     hybrid_shape_unfold.ReplaceElementsToTransfer iRank
        # #     replace_elements_to_transfer = iRank
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeUnfold(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_robot_interfaces.generic_accuracy_profile import GenericAccuracyProfile
from pycatia.dnb_robot_interfaces.generic_motion_profile import GenericMotionProfile
from pycatia.dnb_robot_interfaces.generic_obj_frame_profile import GenericObjFrameProfile
from pycatia.dnb_robot_interfaces.generic_tool_profile import GenericToolProfile
from pycatia.system_interfaces.any_object import AnyObject


class RobControllerFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     RobControllerFactory
                | 
                | Interface to manipulate Robot Controller.
                | Role: This interface provides methods to operate attributes related to robot
                | controller, especially profiles.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rob_controller_factory = com_object

    def create_generic_accuracy_profile(self, o_accuracy_profile: GenericAccuracyProfile) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateGenericAccuracyProfile(GenericAccuracyProfile
                | oAccuracyProfile)
                | 
                |     Creates a Generic Accuracy Profile.
                | 
                |     Parameters:
                | 
                |         oAccuracyProfile
                |             Created Accuracy Profile. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param GenericAccuracyProfile o_accuracy_profile:
        :rtype: None
        """
        return self.rob_controller_factory.CreateGenericAccuracyProfile(o_accuracy_profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_generic_accuracy_profile'
        # # vba_code = """
        # # Public Function create_generic_accuracy_profile(rob_controller_factory)
        # #     Dim oAccuracyProfile (2)
        # #     rob_controller_factory.CreateGenericAccuracyProfile oAccuracyProfile
        # #     create_generic_accuracy_profile = oAccuracyProfile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_generic_motion_profile(self, o_motion_profile: GenericMotionProfile) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateGenericMotionProfile(GenericMotionProfile
                | oMotionProfile)
                | 
                |     Creates a Generic Motion Profile.
                | 
                |     Parameters:
                | 
                |         oMotionProfile
                |             Created Motion Profile. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param GenericMotionProfile o_motion_profile:
        :rtype: None
        """
        return self.rob_controller_factory.CreateGenericMotionProfile(o_motion_profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_generic_motion_profile'
        # # vba_code = """
        # # Public Function create_generic_motion_profile(rob_controller_factory)
        # #     Dim oMotionProfile (2)
        # #     rob_controller_factory.CreateGenericMotionProfile oMotionProfile
        # #     create_generic_motion_profile = oMotionProfile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_generic_obj_frame_profile(self, o_obj_frame_profile: GenericObjFrameProfile) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateGenericObjFrameProfile(GenericObjFrameProfile
                | oObjFrameProfile)
                | 
                |     Creates a Generic Object-Frame Profile.
                | 
                |     Parameters:
                | 
                |         oObjFrameProfile
                |             Created ObjFrame Profile. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param GenericObjFrameProfile o_obj_frame_profile:
        :rtype: None
        """
        return self.rob_controller_factory.CreateGenericObjFrameProfile(o_obj_frame_profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_generic_obj_frame_profile'
        # # vba_code = """
        # # Public Function create_generic_obj_frame_profile(rob_controller_factory)
        # #     Dim oObjFrameProfile (2)
        # #     rob_controller_factory.CreateGenericObjFrameProfile oObjFrameProfile
        # #     create_generic_obj_frame_profile = oObjFrameProfile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_generic_tool_profile(self, o_tool_profile: GenericToolProfile) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateGenericToolProfile(GenericToolProfile
                | oToolProfile)
                | 
                |     Creates a Generic Tool Profile.
                | 
                |     Parameters:
                | 
                |         oToolProfile
                |             Created Tool Profile. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param GenericToolProfile o_tool_profile:
        :rtype: None
        """
        return self.rob_controller_factory.CreateGenericToolProfile(o_tool_profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_generic_tool_profile'
        # # vba_code = """
        # # Public Function create_generic_tool_profile(rob_controller_factory)
        # #     Dim oToolProfile (2)
        # #     rob_controller_factory.CreateGenericToolProfile oToolProfile
        # #     create_generic_tool_profile = oToolProfile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'RobControllerFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_property import ABQProperty
from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.axis_system import AxisSystem


class ABQSpringConnectionProperty(ABQProperty):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQProperty
                |                         ABQSpringConnectionProperty
                | 
                | Represents an Abaqus spring connection property (ABQSpring)
                | object.
                | Role:Access an Abaqus spring connection property object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_spring_connection_property = com_object

    @property
    def axis_sys(self) -> AxisSystem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Axis_sys() As AxisSystem
                | 
                |     Sets or returns the axis system in the spring connection
                |     property.
                | 
                |     Returns:
                |         The object of axis system.

        :rtype: AxisSystem
        """

        return AxisSystem(self.abq_spring_connection_property.Axis_sys)

    @axis_sys.setter
    def axis_sys(self, value: AxisSystem):
        """
        :param AxisSystem value:
        """

        self.abq_spring_connection_property.Axis_sys = value

    @property
    def spring_definition(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SpringDef() As SpringDef_Type
                | 
                |     Sets or returns the definition of spring.
                | 
                |     Returns:
                |         the Definition of spring.
                | 
                |         Legal values:
                |         ABQ_LINE
                |         ABQ_NON_LINEAR

        :rtype: int
        """

        return self.abq_spring_connection_property.SpringDef

    @spring_definition.setter
    def spring_definition(self, value: int):
        """
        :param int value:
        """

        self.abq_spring_connection_property.SpringDef = value

    @property
    def spring_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SpringType() As SpringType_Type
                | 
                |     Sets or returns the type of spring.
                | 
                |     Returns:
                |         The type of spring.
                | 
                |         Legal values:
                |         AXIAL
                |         GENERAL

        :return: enum spring_type_type
        :rtype: int
        """

        return self.abq_spring_connection_property.SpringType

    @spring_type.setter
    def spring_type(self, value: int):
        """
        :param int value: enum spring_type_type
        """

        self.abq_spring_connection_property.SpringType = value

    def add_support_from_reference(self, i_reference: Reference, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromReference(Reference iReference,
                | Reference iSupport)
                | 
                |     Adds support to the spring connection property.
                | 
                |     Parameters:
                | 
                |         iReference
                |             The CATIA Reference specifying the region to which the spring
                |             connection property is applied.
                |         iSupport
                |             The CATIA Reference specifying the region to which the spring
                |             connection property is applied.
                | 
                |             Refer: CATIAReference

        :param Reference i_reference:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_spring_connection_property.AddSupportFromReference(i_reference.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_reference'
        # # vba_code = """
        # # Public Function add_support_from_reference(abq_spring_connection_property)
        # #     Dim iReference (2)
        # #     abq_spring_connection_property.AddSupportFromReference iReference
        # #     add_support_from_reference = iReference
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_linear_stiffness(self, i_dof: int) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLinearStiffness(SpringDof_Type iDof) As double
                | 
                |     Gets the linear stiffness of the spring given the degree of
                |     freedom.
                | 
                |     Parameters:
                | 
                |         iDof
                |             The degree of freedom for which stiffness is
                |             asked.
                | 
                | 
                |             Legal values:
                | 
                |             U1_DOF
                |             U2_DOF
                |             U3_DOF
                |             UR1_DOF
                |             UR2_DOF
                |             UR3_DOF
                | 
                |         oStiffnessValue
                |             The stiffnessvalue.

        :param int i_dof: enum spring_dof_type
        :rtype: float
        """
        return self.abq_spring_connection_property.GetLinearStiffness(i_dof)

    def get_non_linear_stiffness(self, i_dof: int, o_force_array: tuple, o_disp_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetNonLinearStiffness(SpringDof_Type iDof,
                | CATSafeArrayVariant oForceArray,
                | CATSafeArrayVariant oDispArray)
                | 
                |     Gets the non-linear stiffness of the spring in the form of array, given the
                |     degree of freedom.
                | 
                |     Parameters:
                | 
                |         iDof
                |             The degree of freedom for which stiffness is
                |             asked.
                | 
                | 
                |             Legal values:
                | 
                |             U1_DOF
                |             U2_DOF
                |             U3_DOF
                |             UR1_DOF
                |             UR2_DOF
                |             UR3_DOF
                | 
                |         oForceArray
                |             The array of force values.
                |         oDispArray
                |             The array of displacement values.
                | 
                |             Refer: CATSafeArrayVariant

        :param int i_dof: enum spring_dof_type
        :param tuple o_force_array:
        :param tuple o_disp_array:
        :rtype: None
        """
        return self.abq_spring_connection_property.GetNonLinearStiffness(i_dof, o_force_array, o_disp_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_non_linear_stiffness'
        # # vba_code = """
        # # Public Function get_non_linear_stiffness(abq_spring_connection_property)
        # #     Dim iDof (2)
        # #     abq_spring_connection_property.GetNonLinearStiffness iDof
        # #     get_non_linear_stiffness = iDof
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def read_stiffness_data_from_file(self, i_dof: int, i_file_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ReadStiffnessDataFromFile(SpringDof_Type iDof,
                | CATBSTR iFileName)
                | 
                |     Reads stiffness data from a text file for a spring connection
                |     property.
                | 
                |     Parameters:
                | 
                |         iDof
                |             The degree of freedom for which stiffness is
                |             asked.
                | 
                |             Legal values:
                |             U1_DOF
                |             U2_DOF
                |             U3_DOF
                |             UR1_DOF
                |             UR2_DOF
                |             UR3_DOF
                | 
                |         iFileName
                |             The complete path of the text file which contains the stiffness
                |             data.

        :param int i_dof: enum spring_dof_type
        :param str i_file_name:
        :rtype: None
        """
        return self.abq_spring_connection_property.ReadStiffnessDataFromFile(i_dof, i_file_name)

    def remove_axis_system(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAxisSystem()

        :rtype: None
        """
        return self.abq_spring_connection_property.RemoveAxisSystem()

    def remove_dof(self, i_dof: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveDof(SpringDof_Type iDof)
                | 
                |     Unsets the stiffness of the spring for given degree of
                |     freedom.
                | 
                |     Parameters:
                | 
                |         iDof
                |             The degree of freedom for which stiffness is set.
                | 
                |             Legal values:
                |             U1_DOF
                |             U2_DOF
                |             U3_DOF
                |             UR1_DOF
                |             UR2_DOF
                |             UR3_DOF

        :param int i_dof: enum spring_dof_type
        :rtype: None
        """
        return self.abq_spring_connection_property.RemoveDof(i_dof)

    def set_linear_stiffness(self, i_dof: int, i_stiffness_value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLinearStiffness(SpringDof_Type iDof,
                | double iStiffnessValue)
                | 
                |     Sets the linear stiffness of the spring given the degree of
                |     freedom.
                | 
                |     Parameters:
                | 
                |         iDof
                |             The degree of freedom for which stiffness is set.
                | 
                |             Legal values:
                |             U1_DOF
                |             U2_DOF
                |             U3_DOF
                |             UR1_DOF
                |             UR2_DOF
                |             UR3_DOF
                | 
                |         iStiffnessValue
                |             The stiffnessvalue.

        :param int i_dof: enum spring_dof_type
        :param float i_stiffness_value:
        :rtype: None
        """
        return self.abq_spring_connection_property.SetLinearStiffness(i_dof, i_stiffness_value)

    def set_non_linear_stiffness(self, i_dof: int, i_force_array: tuple, i_disp_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetNonLinearStiffness(SpringDof_Type iDof,
                | CATSafeArrayVariant iForceArray,
                | CATSafeArrayVariant iDispArray)
                | 
                |     Sets the non-linear stiffness of the spring in the form of array, given the
                |     degree of freedom.
                | 
                |     Parameters:
                | 
                |         iDof
                |             The degree of freedom for which stiffness is
                |             asked.
                |
                |             Legal values:
                |             U1_DOF
                |             U2_DOF
                |             U3_DOF
                |             UR1_DOF
                |             UR2_DOF
                |             UR3_DOF
                | 
                |         iForceArray
                |             The array of force values.
                |         iDispArray
                |             The array of displacement values.
                |             The value in displacement array must be greater than previous value.
                | 
                |             Refer: CATSafeArrayVariant

        :param int i_dof: enum spring_dof_type
        :param tuple i_force_array:
        :param tuple i_disp_array:
        :rtype: None
        """
        return self.abq_spring_connection_property.SetNonLinearStiffness(i_dof, i_force_array, i_disp_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_non_linear_stiffness'
        # # vba_code = """
        # # Public Function set_non_linear_stiffness(abq_spring_connection_property)
        # #     Dim iDof (2)
        # #     abq_spring_connection_property.SetNonLinearStiffness iDof
        # #     set_non_linear_stiffness = iDof
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQSpringConnectionProperty(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.fitting_interfaces.sampled import Sampled
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Sampleds(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Sampleds
                | 
                | The collection of all the Sampled objects currently contained in the current
                | document.
                | A Sampled object is the base type for Track objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Sampled)
        self.sampleds = com_object

    def add(self) -> Sampled:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add() As Sampled
                | 
                |     Creates a new Sampled object and adds it to the Sampleds
                |     collection.
                | 
                |     Returns:
                |         The created Sampled 
                |     Example:
                |         The following example creates a Sampled (called newSampled) with in the
                |         Sampleds collection.
                | 
                |          Set newSampled = Sampleds.Add

        :rtype: Sampled
        """
        return Sampled(self.sampleds.Add())

    def add_from_sel(self) -> Sampled:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddFromSel() As Sampled
                | 
                |     Creates a new Sampled from the selection and adds it to the Sampleds
                |     collection.
                | 
                |     Returns:
                |         The created Sampled 
                |     Example:
                |         The following example creates a Sampled (called newSampled) with in the
                |         Sampleds collection.
                | 
                |          Set newSampled = Sampleds.Add

        :rtype: Sampled
        """
        return Sampled(self.sampleds.AddFromSel())

    def item(self, i_index: cat_variant) -> Sampled:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Sampled
                | 
                |     Returns a CATIASampled object using its index from the CATIASampled
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the sampled to retrieve from the collection of
                |             sampleds. Numerically, the index value corresponds to the rank of the sampled
                |             in the collection (ie. the first is 1, second is 2, ...).
                |             
                | 
                |     Returns:
                |         The retrieved Sampled 
                |     Example:
                |         The following example retrieves the second Sampled from the Sampleds
                |         collection of the active document.
                | 
                |          Dim newSampled as Sampled
                |          Set newSampled = Sampleds.Item (2)

        :param cat_variant i_index:
        :rtype: Sampled
        """
        return Sampled(self.sampleds.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a CATIASampled object from the CATIASampled
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the sampled to remove from the collection of sampleds.
                |             Numerically, the index value corresponds to the rank of the sampled in the
                |             collection (ie. the first is 1, second is 2, ...).
                |             
                |         Example:
                |             The following example removes the third Sampled from the Sampleds
                |             collection of the active document.
                | 
                |              Sampleds.Remove (3)

        :param cat_variant i_index:
        :rtype: None
        """
        return self.sampleds.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(sampleds)
        # #     Dim iIndex (2)
        # #     sampleds.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Sampleds(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_robot_interfaces.parameter_profiles import ParameterProfiles
from pycatia.system_interfaces.any_object import AnyObject


class ParameterProfilesFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ParameterProfilesFactory
                | 
                | Interface to manage an user-defined applicative parameter profile(s) defined on
                | a robot controller.
                | 
                | Role: This interface allows the end-user to handle Applicative parameter
                | profiles on a robot controller. It works on both:
                | 
                |     robots created using V5 mechanisms
                |     robots imported from DENEB D5
                |
                | Applicative profiles are defined using a Feature Dictionary Editor application.
                | The application will save CATFct files that must be referenced with a file
                | Profile.xml, referenced through the environment variable CATDisciplinePath. For
                | more information, please refer to the Device Building product documentation in
                | the Advanced Tasks section on the setup.
                | 
                | To get a handle on the robot, the product must be the assembly node
                | representing the robot (the one with a robot icon).
                | 
                | The following code snippet shows how to retrieve the handle on the
                | factory.
                | 
                |    'current document is a product
                |    'the root product is a robot
                | 
                |    'retrieving the root product
                |    Dim MyProduct As Product
                |    Set MyProduct = CATIA.ActiveDocument.Product
                | 
                |    'retrieving the handle
                |    Dim MyProfileFactory As ParameterProfilesFactory
                |    Set MyProfileFactory = MyProduct.GetTechnologicalObject("ParameterProfilesFactory")
                |    ...
                |    'retrieving the list of profiles as an array
                |    Dim MyListOfProfiles() As ParameterProfiles
                |    MyProfileFactory.GetAllProfileInstances(MyListOfProfiles)
                | 
                |    'loop for each profile
                |    Dim MyCurrentProfile as ParameterProfiles
                |    For Each MyCurrentProfile In MyListOfProfiles
                |       ...
                |    Next
                |
                | ParameterProfiles CATSafeArrayVariant
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.parameter_profiles_factory = com_object

    def create_profile_instance(
            self,
            i_profile_type: str,
            i_instance_name: str,
            o_app_parameter_profile: ParameterProfiles
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateProfileInstance(CATBSTR iProfileType,
                | CATBSTR iInstanceName,
                | ParameterProfiles oAppParameterProfile)
                | 
                |     Instantiates a particular profile type. The profile type is user-defined:
                |     it is the name the user has set when defining the profile in the CATFct
                |     file.
                | 
                |     Parameters:
                | 
                |         iProfileType
                |             Profile type name for which the instance has to be created (input)
                |             
                |         iInstanceName
                |             Desired instance name for the instance to be created( input)
                |             
                |         oAppParameterProfile
                |             Handle to the profile instance thus created (output)
                |
                |     Example:
                |
                |            ' declaration of 2 variable handles
                |            Dim MyNewProfile As ParameterProfiles
                |            Dim MyProfileFactory As ParameterProfilesFactory
                | 
                |            ' valuation 
                |            Set MyProfileFactory= ...
                | 
                |            ' declaration of variables for names
                |            Dim InstanceName
                |            Dim DefaultName
                |            DefaultName = "MyChoice." 'example
                | 
                |            'Create 10 instances of the profile type
                |            MyProfileType
                |            For i=1 to 10
                |                'concatenation of default name and index
                |                InstanceName = DefaultName & i
                |                ParmProfileFact.CreateProfileInstance(
                |                "MyProfileType",
                |                InstanceName,
                |                MyNewProfile)
                |            Next

        :param str i_profile_type:
        :param str i_instance_name:
        :param ParameterProfiles o_app_parameter_profile:
        :rtype: None
        """
        return self.parameter_profiles_factory.CreateProfileInstance(
            i_profile_type,
            i_instance_name,
            o_app_parameter_profile.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_profile_instance'
        # # vba_code = """
        # # Public Function create_profile_instance(parameter_profiles_factory)
        # #     Dim iProfileType (2)
        # #     parameter_profiles_factory.CreateProfileInstance iProfileType
        # #     create_profile_instance = iProfileType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def delete_profile_instance(self, io_parameter_profile: ParameterProfiles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeleteProfileInstance(ParameterProfiles
                | ioParameterProfile)
                | 
                |     Deletes a particular profile instance
                | 
                |     Parameters:
                | 
                |         ioParameterProfile
                |             Handle to the profile instance which should be deleted( input)
                |
                |     Example:
                |
                |            ' declaration of 2 variable handles
                |            Dim MyProfileToDelete As ParameterProfiles
                |            Dim MyProfileFactory As ParameterProfilesFactory
                | 
                |            ' valuation 
                |            Set MyProfileToDelete= ...
                |            Set MyProfileFactory= ...
                | 
                |            'deletion of the object
                |            MyProfileFactory.DeleteProfileInstance(MyProfileToDelete);

        :param ParameterProfiles io_parameter_profile:
        :rtype: None
        """
        return self.parameter_profiles_factory.DeleteProfileInstance(io_parameter_profile.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete_profile_instance'
        # # vba_code = """
        # # Public Function delete_profile_instance(parameter_profiles_factory)
        # #     Dim ioParameterProfile (2)
        # #     parameter_profiles_factory.DeleteProfileInstance ioParameterProfile
        # #     delete_profile_instance = ioParameterProfile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_all_profile_instances(self, o_all_instances_on_product: tuple) -> ParameterProfiles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAllProfileInstances(CATSafeArrayVariant
                | oAllInstancesOnProduct)
                | 
                |     Gets the array of all the handles of the profile instances (belonging to
                |     all profile types)
                | 
                |     Parameters:
                | 
                |         oAllInstancesOnProduct
                |             The array of all the handles to all the profile instances of all
                |             the profile types(output) 
                | 
                |     Example:
                |
                |            'retrieving the handle on the profile factory
                |            Dim MyProfileFactory As ParameterProfilesFactory
                |            set MyProfileFactory = ...
                |            ...
                |            'retrieving the list of profiles as an array
                |            Dim MyListOfProfiles() As ParameterProfiles
                |            MyProfileFactory.GetAllProfileInstances(MyListOfProfiles)
                |
                |            'loop for each profile
                |            Dim MyCurrentProfile as ParameterProfiles
                |            For Each MyCurrentProfile In MyListOfProfiles
                |               ...
                |            Next

        :param tuple o_all_instances_on_product:
        :rtype: ParameterProfiles
        """
        return ParameterProfiles(self.parameter_profiles_factory.GetAllProfileInstances(o_all_instances_on_product))
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_all_profile_instances'
        # # vba_code = """
        # # Public Function get_all_profile_instances(parameter_profiles_factory)
        # #     Dim oAllInstancesOnProduct (2)
        # #     parameter_profiles_factory.GetAllProfileInstances oAllInstancesOnProduct
        # #     get_all_profile_instances = oAllInstancesOnProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_profile_instance(self, i_instance_name: str, o_profile_instance: ParameterProfiles) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetProfileInstance(CATBSTR iInstanceName,
                | ParameterProfiles oProfileInstance)
                | 
                |     Gets the handle to the profile instance against the instance
                |     name
                | 
                |     Parameters:
                | 
                |         iInstanceName
                |             The name of the profile instance(input) 
                |         oProfileInstance
                |             Handle to the profile instance which has the above name( output)
                |
                |     Example:
                |
                |            'retrieving the handle on the profile factory
                |            Dim MyProfileFactory As ParameterProfilesFactory
                |            set MyProfileFactory = ...
                |            ...
                |            'defining the type
                |            Dim MyProfileName
                |            set MyProfileName= "MyProfile.1" 'example
                |            
                |            'retrieving the profile
                |            Dim MyCurrentProfile as ParameterProfiles
                |            MyProfileFactory.GetProfileInstances(
                |               MyProfileName,
                |               MyListOfProfiles)

        :param str i_instance_name:
        :param ParameterProfiles o_profile_instance:
        :rtype: None
        """
        return self.parameter_profiles_factory.GetProfileInstance(i_instance_name, o_profile_instance.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_profile_instance'
        # # vba_code = """
        # # Public Function get_profile_instance(parameter_profiles_factory)
        # #     Dim iInstanceName (2)
        # #     parameter_profiles_factory.GetProfileInstance iInstanceName
        # #     get_profile_instance = iInstanceName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_profile_instances(self, i_profile_type: str, o_profiles: tuple) -> ParameterProfiles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetProfileInstances(CATBSTR iProfileType,
                | CATSafeArrayVariant oProfiles)
                | 
                |     Gets the array of handles of the profile instances belonging to a
                |     particular profile type
                | 
                |     Parameters:
                | 
                |         iProfileType
                |             The Profile Type (input) 
                |         oProfiles
                |             The array of handles to the profile instances of the type specified
                |             above(output) 
                | 
                |     Example:
                |
                |            'retrieving the handle on the profile factory
                |            Dim MyProfileFactory As ParameterProfilesFactory
                |            set MyProfileFactory = ...
                |            ...
                |            'defining the type
                |            Dim MyProfileType
                |            set MyProfileType = "MyProfileType" 'example
                |            
                |            'retrieving the list of profiles as an array
                |            Dim MyListOfProfiles() As ParameterProfiles
                |            MyProfileFactory.GetProfileInstances(
                |                                                   MyProfileType,
                |                                                   MyListOfProfiles)
                |
                |            'loop for each profile
                |            Dim MyCurrentProfile as ParameterProfiles
                |            For Each MyCurrentProfile In MyListOfProfiles
                |               ...
                |            Next

        :param str i_profile_type:
        :param tuple o_profiles:
        :rtype: ParameterProfiles
        """
        return ParameterProfiles(self.parameter_profiles_factory.GetProfileInstances(i_profile_type, o_profiles))
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_profile_instances'
        # # vba_code = """
        # # Public Function get_profile_instances(parameter_profiles_factory)
        # #     Dim iProfileType (2)
        # #     parameter_profiles_factory.GetProfileInstances iProfileType
        # #     get_profile_instances = iProfileType
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ParameterProfilesFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PSPId(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspID
                | 
                | Represents the interface to generate and set IDs for the Distributive System
                | Objects.
                | Role: This is the interface for Plant Ship object ID
                | generation.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_id = com_object

    def gen_and_put_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GenAndPutID() As CATBSTR
                | 
                |     Returns the Generated ID with the sequence number and is stored on the
                |     object.
                | 
                |     Returns:
                |         ID generated
                |
                |     Example:
                |
                |          Dim objThisIntf As PspID
                |          Dim iStrVar1 As String
                |           ...
                |          iStrVar1 =objThisIntf.GenAndPutID

        :rtype: str
        """
        return self.psp_id.GenAndPutID()

    def gen_and_put_id_no_gen_seq_num(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GenAndPutIDNoGenSeqNum() As CATBSTR
                | 
                |     Generates ID without the sequence number and is stored on the
                |     object.
                | 
                |     Returns:
                |         ID generated
                |
                |     Example:
                |
                |          Dim objThisIntf As PspID
                |          Dim iStrVar1 As String
                |           ...
                |          iStrVar1 =objThisIntf.GenAndPutIDNoGenSeqNum

        :rtype: str
        """
        return self.psp_id.GenAndPutIDNoGenSeqNum()

    def gen_id_no_gen_seq_num(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GenIDNoGenSeqNum() As CATBSTR
                | 
                |     Generates ID without the sequence number( if not set previously) and is not
                |     stored on the object.
                | 
                |     Parameters:
                | 
                |         oGeneratedID
                |             ID generated 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspID
                |          Dim iStrVar1 As String
                |           ...
                |          iStrVar1 =objThisIntf.GenIDNoGenSeqNum

        :rtype: str
        """
        return self.psp_id.GenIDNoGenSeqNum()

    def get_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetID() As CATBSTR
                | 
                |     Gets ID for the object.
                | 
                |     Returns:
                |         ID of the object. 
                |     Example:
                |
                |          Dim objThisIntf As PspID
                |          Dim iStrVar1 As String
                |           ...
                |          iStrVar1 =objThisIntf.GetID

        :rtype: str
        """
        return self.psp_id.GetID()

    def get_local_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLocalID() As CATBSTR
                | 
                |     Retrieves local ID of the object.
                | 
                |     Returns:
                |         Local ID generated
                |
                |     Example:
                |
                |          Dim objThisIntf As PspID
                |          Dim iStrVar1 As String
                |           ...
                |          iStrVar1 =objThisIntf.GetLocalID

        :rtype: str
        """
        return self.psp_id.GetLocalID()

    def is_id_generated(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsIDGenerated() As boolean
                | 
                |     Checks if the ID on the object is generated( based on the ID
                |     Schema).
                | 
                |     Parameters:
                | 
                |         oBIsGenerated
                |             TRUE if ID is generated from the ID schema 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspID
                |          Dim bVar1 As boolean
                |           ...
                |          bVar1 =objThisIntf.IsIDGenerated

        :rtype: bool
        """
        return self.psp_id.IsIDGenerated()

    def set_id(self, i_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetID(CATBSTR iID)
                | 
                |     Sets ID for the object.
                | 
                |     Parameters:
                | 
                |         oID
                |             ID to be set. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspID
                |          Dim iStrVar1 As String
                |           ...
                |          objThisIntf.SetID iStrVar1

        :param str i_id:
        :rtype: None
        """
        return self.psp_id.SetID(i_id)

    def __repr__(self):
        return f'PSPId(name="{self.name}")'
